# Task List

- item 1
  - item A
  - item B more text
    - item a
    - item b
    - item c
  - item C
- item 2
- item 3

# Mixed Lists

- item 1
  - item A
  - item B more text
    1. item a
    2. item b
    3. item c
  - item C
- item 2
- item 3

# Really Mixed Lists

- item 1
  - item A
  - item B more text
    1. item a
    2. item b
    3. item c
  - item C
- item 2
- item 3

# Test Tasklists in Subparagraphs

- item 1

  - item A

  - item a